@@ -1,5 +1,5 @@
 import json
-from SimConf.propertys import *
+from propertys import *
 
 
 class SimConf:
@@ -81,7 +81,7 @@ class SimConf:
 
 if __name__ == '__main__':
     default_atr = [1,2,3]
-    cnf = SimConf(filename="35", default_atr=default_atr)
+    cnf = SimConf(filename='35', default_atr=default_atr)
     # cnf["tt"] = [1,2,3,4, {"atr": 12., "booll":False}]
     # print(cnf["tt"][-1]["booll"])
     cnf.print_all()
